@@ -5,13 +5,16 @@ from django.core.management.base import BaseCommand, CommandError
 from django.conf import settings
 
 
+from simple_deploy.management.commands.utils import deploy_messages as d_msgs
+
+
 class Command(BaseCommand):
     """Perform the initial deployment of a simple project.
     Configure as much as possible automatically.
     """
 
     def add_arguments(self, parser):
-        """Parse CLI options."""
+        """Define CLI options."""
 
         parser.add_argument('--automate-all',
             help="Automate all aspects of deployment?",
@@ -20,8 +23,10 @@ class Command(BaseCommand):
 
     def handle(self, *args, **options):
         # DEV: Later, this should check for the platform to deploy to.
-        #   Assume deploying to Heroku for now.
-        self.stdout.write("Auto-configuring project for deployment to Heroku...")
+        #   Will also probably move all platform-specific steps to 
+        #   separate files.
+        # Assume we're deploying to Heroku for now.
+        self.stdout.write("Configuring project for deployment to Heroku...")
 
         self._parse_cli_options(options)
         self._prep_automate_all()
@@ -50,23 +55,15 @@ class Command(BaseCommand):
 
     def _prep_automate_all(self):
         """Do intial work for automating entire process."""
-        # Confirm automation.
-        # Call heroku create.
 
         # Skip this prep work if --automate-all not used.
         if not self.automate_all:
             return
 
-        msg = "\n\nThe --automate-all flag means simple_deploy will:"
-        msg += "\n- Run `heroku create` for you, to create a new Heroku project;"
-        msg += "\n- Commit all changes to your project that are necessary for deployment;"
-        msg += "\n  These changes will be committed to the current branch, you"
-        msg += "\n    may want to make a new branch for this work."
-        msg += "\n- Push these changes to Heroku;"
-        msg += "\n- Run `heroku migrate` to set up the remote database;"
-        msg += "\n- Call `heroku open` to open your deployed project in a new browser tab."
-        self.stdout.write(msg)
+        # Confirm the user knows exactly what will be automated.
+        self.stdout.write(d_msgs.confirm_automate_all)
 
+        # Get confirmation.
         confirmed = ''
         while confirmed.lower() not in ('y', 'yes', 'n', 'no'):
             prompt = "\nAre you sure you want to do this? (yes|no) "
@@ -75,52 +72,32 @@ class Command(BaseCommand):
                 self.stdout.write("  Please answer yes or no.")
 
         if confirmed.lower() in ('y', 'yes'):
-            pass
             self.stdout.write("  Running `heroku create`...")
             subprocess.run(['heroku', 'create'])
         else:
-            # Quit and have the user run the command again.
-            self.stdout.write("\nOkay. Canceling this run.")
-            self.stdout.write("  If you want to configure your project for deployment,")
-            self.stdout.write("  run simple_deploy again without the --automate-all flag.")
-            sys.exit()
+            # Quit and have the user run the command again; don't assume not
+            #   wanting to automate means they want to configure.
+            self.stdout.write(d_msgs.cancel_automate_all)
 
 
     def _get_heroku_app_info(self):
         """Get info about the Heroku app we're pushing to."""
-        # This command assumes the user has already run 'heroku create'.
-        #   If they haven't, we'll quit and tell them to.
-        #   If they have, we'll get the information we'll need later in the
-        #     deployment process.
-        #   This is all done through the `heroku apps:info` command.
-        #
-        #  If they haven't run heroku create, output should go to stderr
-        #    and we simply won't have an app name. So, blank app name -> 
-        #    tell user to run 'heroku create and then run this command again.
-        #  We could consider running this for the user, but we probably want them to 
-        #    interact with heroku to some degree.
-        #  What happens if they haven't installed Heroku CLI?
-        #    Telling them they need to run heroku create probably covers that
-        #    for now.
-
+        # We assume the user has already run 'heroku create', or --automate-all
+        #   has run it. If it hasn't been run, we'll quit and tell them to do so.
         self.stdout.write("  Inspecting Heroku app...")
-
         apps_info = subprocess.run(["heroku", "apps:info"], capture_output=True)
-        # print('raw apps info:\n', apps_info)
 
         # Turn stdout info into a list of strings that we can then parse.
+        #   If no app exists, stdout is empty and the output went to stderr.
         apps_info = apps_info.stdout.decode().split('\n')
-        # print('split apps info:\n', apps_info)
-
         self.heroku_app_name = apps_info[0].removeprefix('=== ')
-        self.stdout.write(f"    Found Heroku app: {self.heroku_app_name}")
 
-        if not self.heroku_app_name:
-            msg = "\n\nNo Heroku app name has been detected."
-            msg += "\n\nThe simple_deploy command assumes you have already run 'heroku create' to start the deployment process. Please run 'heroku create', and then run 'python manage.py simple_deploy' again."
-            msg += "\n\nIf you haven't already done so, you will need to install the Heroku CLI: https://devcenter.heroku.com/articles/heroku-cli"
+        if self.heroku_app_name:
+            self.stdout.write(f"    Found Heroku app: {self.heroku_app_name}")
+        else:
+            # Let user know they need to run `heroku create`.
+            raise CommandError(d_msgs.no_heroku_app_detected)
 
-            raise CommandError(msg)
 
     def _set_heroku_env_var(self):
         """Set a config var to indicate when we're in the Heroku environment.
@@ -131,6 +108,7 @@ class Command(BaseCommand):
         self.stdout.write("    Set ON_HEROKU=1.")
         self.stdout.write("    This is used to define Heroku-specific settings.")
 
+
     def _inspect_project(self):
         """Inspect the project, and pull information needed by multiple steps.
         """
@@ -143,9 +121,17 @@ class Command(BaseCommand):
         self.project_root = settings.BASE_DIR
         self.settings_path = f"{self.project_root}/{self.project_name}/settings.py"
 
-        # Which dependency management approach are we using?
-        #   req_txt, pipenv, poetry?
-        #   In a simple project, I don't think we should find both Pipfile
+        self._get_dep_man_approach()
+        self._get_current_requirements()
+        self._get_heroku_settings()
+
+
+    def _get_dep_man_approach(self):
+        """Identify which dependency management approach the project uses.
+        req_txt, poetry, or pipenv.
+        """
+
+        # In a simple project, I don't think we should find both Pipfile
         #   and requirements.txt. However, if there's both, prioritize Pipfile.
         self.using_req_txt = 'requirements.txt' in os.listdir(self.project_root)
 
@@ -166,7 +152,10 @@ class Command(BaseCommand):
             subprocess.run(export_cmd_parts)
             self.using_req_txt = True
 
-        # What requirements are already listed?
+
+    def _get_current_requirements(self):
+        """Get current project requirements, before adding any new ones.
+        """
         if self.using_req_txt:
             # Build path to requirements.txt.
             self.req_txt_path = f"{self.project_root}/requirements.txt"
@@ -183,10 +172,14 @@ class Command(BaseCommand):
             # Get list of requirements.
             self.requirements = self._get_pipfile_requirements()
 
-        # Store any heroku-specific settings already in place.
-        #   If any have already been written, we don't want to add them again.
-        #   This assumes a section at the end, starting with a check for 
-        #   'ON_HEROKU' in os.environ.
+
+    def _get_heroku_settings(self):
+        """Get any heroku-specific settings that are already in place.
+        """
+        # If any heroku settings have already been written, we don't want to
+        #  add them again. This assumes a section at the end, starting with a
+        #  check for 'ON_HEROKU' in os.environ.
+
         with open(self.settings_path) as f:
             settings_lines = f.readlines()
 
@@ -197,27 +190,18 @@ class Command(BaseCommand):
                 self.found_heroku_settings = True
             if self.found_heroku_settings:
                 self.current_heroku_settings_lines.append(line)
-        # print(self.current_heroku_settings_lines)
+
 
     def _add_simple_deploy_req(self):
         """Add this project to requirements.txt."""
-        # Since the simple_deploy app is in INCLUDED_APPS, it needs to be in
-        #   requirements.txt. If it's not, Heroku will reject the push.
-        self.stdout.write("\n  Looking for django-simple-deploy in requirements...")
-
+        # Since the simple_deploy app is in INCLUDED_APPS, it needs to be
+        #   required. If it's not, Heroku will reject the push.
+        # This step isn't needed for Pipenv users, because when they install
+        #   django-simple-deploy it's automatically added to Pipfile.
         if self.using_req_txt:
-            # DEV: This is the correct code once this project is on PyPI.
-            #   Also, once this is updated, integration test will need to be updated.
-            #   (Substitution for dev branch install address.)
+            self.stdout.write("\n  Looking for django-simple-deploy in requirements.txt...")
             self._add_req_txt_pkg('django-simple-deploy')
-            # self._add_req_txt_pkg('git+git://github.com/ehmatthes/django-simple-deploy')
-        elif self.using_pipenv:
-            # There's nothing to do here. When you use Pipenv to install something,
-            #   it automatically gets added to Pipfile, so simple-deploy should
-            #   already be here. There's no separate step like "pip freeze".
-            # Modify this later if some people are using a Pipenv approach that
-            #   doesn't automatically add installed packages to Pipfile.
-            pass
+
 
     def _generate_procfile(self):
         """Create Procfile, if none present."""
@@ -242,55 +226,39 @@ class Command(BaseCommand):
     def _add_gunicorn(self):
         """Add gunicorn to project requirements."""
         self.stdout.write("\n  Looking for gunicorn...")
-        
+
         if self.using_req_txt:
             self._add_req_txt_pkg('gunicorn')
         elif self.using_pipenv:
-            # Here.
             self._add_pipenv_pkg('gunicorn')
 
 
     def _check_allowed_hosts(self):
         """Make sure project can be served from heroku."""
-        # DEV: Still more nesting than I like here, still needs some refactoring.
+        # DEV: Refactor to reduce nesting.
 
         self.stdout.write("\n  Making sure project can be served from Heroku...")
         heroku_host = f"{self.heroku_app_name}.herokuapp.com"
 
         if heroku_host in settings.ALLOWED_HOSTS:
             self.stdout.write(f"    Found {heroku_host} in ALLOWED_HOSTS.")
-
         elif 'herokuapp.com' in settings.ALLOWED_HOSTS:
+            # This is a generic entry that allows serving from any heroku URL.
             self.stdout.write("    Found 'herokuapp.com' in ALLOWED_HOSTS.")
-
         elif not settings.ALLOWED_HOSTS:
-            # Only add this host if it's not already listed in the heroku-
-            #   specific section.
             new_setting = f"ALLOWED_HOSTS.append('{heroku_host}')"
-            already_set = self._check_current_heroku_settings(new_setting)
-
-            if not already_set:
-                with open(self.settings_path, 'a') as f:
-                    self._prep_heroku_setting(f)
-                    f.write(f"\n    {new_setting}")
-
-                    self.stdout.write(f"    Added {heroku_host} to ALLOWED_HOSTS for the deployed project.")
-            else:
-                self.stdout.write(f"    Found {heroku_host} in ALLOWED_HOSTS for the deployed project.")
-
+            msg_added = f"    Added {heroku_host} to ALLOWED_HOSTS for the deployed project."
+            msg_already_set = f"    Found {heroku_host} in ALLOWED_HOSTS for the deployed project."
+            self._add_heroku_setting(new_setting, msg_added, msg_already_set)
         else:
-            msg = f"\n\nYour ALLOWED_HOSTS setting is not empty, and it does not contain {heroku_host}. ALLOWED_HOSTS is a critical security setting. It is empty by default, which means you or someone else has decided where this project can be hosted."
-            msg += "\n\nYour ALLOWED_HOSTS setting currently contains the following entries:"
-            msg += f"\n{settings.ALLOWED_HOSTS}"
-            msg += f"\n\nWe do not know enough about your project to add to or override this setting. If you want to continue with this deployment, make sure ALLOWED_HOSTS is either empty, or contains the host {heroku_host}."
-            msg += "\n\nOnce you have addressed this issue, you can run the simple_deploy command again, and it will pick up where it left off."
-
+            # Let user know there's a nonempty ALLOWED_HOSTS, that doesn't 
+            #   contain the current Heroku URL.
+            msg = d_msgs.allowed_hosts_not_empty_msg(heroku_host)
             raise CommandError(msg)
 
 
     def _configure_db(self):
-        """This method is responsible for adding required db-related packages,
-        and modifying settings for the Heroku db.
+        """Add required db-related packages, and modify settings for Heroku db.
         """
         self.stdout.write("\n  Configuring project for Heroku database...")
         self._add_db_packages()
@@ -316,96 +284,75 @@ class Command(BaseCommand):
         self.stdout.write("   Checking Heroku db settings...")
 
         # Import dj-database-url.
-        # DEV: To refactor this, write a method to take in new setting, msg
-        #   if needed to set it, msg if already set.
         new_setting = "import dj_database_url"
-        already_set = self._check_current_heroku_settings(new_setting)
-        if not already_set:
-            with open(self.settings_path, 'a') as f:
-                self._prep_heroku_setting(f)
-                f.write(f"\n    {new_setting}")
-            self.stdout.write("    Added import statement for dj-database-url.")
-        else:
-            self.stdout.write("    Found import statement for dj-database-url.")
+        msg_added = "    Added import statement for dj-database-url."
+        msg_already_set = "    Found import statement for dj-database-url."
+        self._add_heroku_setting(new_setting, msg_added, msg_already_set)
 
         # Configure db.
         new_setting = "DATABASES = {'default': dj_database_url.config(default='postgres://localhost')}"
-        already_set = self._check_current_heroku_settings(new_setting)
-        if not already_set:
-            with open(self.settings_path, 'a') as f:
-                self._prep_heroku_setting(f)
-                f.write(f"\n    {new_setting}")
-            self.stdout.write("    Added setting to configure Postgres on Heroku.")
-        else:
-            self.stdout.write("    Found setting to configure Postgres on Heroku.")
+        msg_added = "    Added setting to configure Postgres on Heroku."
+        msg_already_set = "    Found setting to configure Postgres on Heroku."
+        self._add_heroku_setting(new_setting, msg_added, msg_already_set)
 
 
     def _configure_static_files(self):
         """Configure static files for Heroku deployment."""
 
-        # Add whitenoise to requirements.
         self.stdout.write("\n  Configuring static files for Heroku deployment...")
+
+        # Add whitenoise to requirements.
         self.stdout.write("    Adding staticfiles-related packages...")
         if self.using_req_txt:
             self._add_req_txt_pkg('whitenoise')
         elif self.using_pipenv:
             self._add_pipenv_pkg('whitenoise')
 
-        # Modify settings.
-        # DEV: There are three lines here; this can easily be refactored.
+        # Modify settings, and add a directory for static files.
+        self._add_static_file_settings()
+        self._add_static_file_directory()
+
+
+    def _add_static_file_settings(self):
+        """Add all settings needed to manage static files."""
         self.stdout.write("    Configuring static files settings...")
 
         new_setting = "STATIC_ROOT = os.path.join(BASE_DIR, 'staticfiles')"
-        already_set = self._check_current_heroku_settings(new_setting)
-        if not already_set:
-            with open(self.settings_path, 'a') as f:
-                self._prep_heroku_setting(f)
-                f.write(f"\n    {new_setting}")
-            self.stdout.write("    Added STATIC_ROOT setting for Heroku.")
-        else:
-            self.stdout.write("    Found STATIC_ROOT setting for Heroku.")
+        msg_added = "    Added STATIC_ROOT setting for Heroku."
+        msg_already_set = "    Found STATIC_ROOT setting for Heroku."
+        self._add_heroku_setting(new_setting, msg_added, msg_already_set)
 
         new_setting = "STATIC_URL = '/static/'"
-        already_set = self._check_current_heroku_settings(new_setting)
-        if not already_set:
-            with open(self.settings_path, 'a') as f:
-                self._prep_heroku_setting(f)
-                f.write(f"\n    {new_setting}")
-            self.stdout.write("    Added STATIC_URL setting for Heroku.")
-        else:
-            self.stdout.write("    Found STATIC_URL setting for Heroku.")
+        msg_added = "    Added STATIC_URL setting for Heroku."
+        msg_already_set = "    Found STATIC_URL setting for Heroku."
+        self._add_heroku_setting(new_setting, msg_added, msg_already_set)
 
         new_setting = "STATICFILES_DIRS = (os.path.join(BASE_DIR, 'static'),)"
-        already_set = self._check_current_heroku_settings(new_setting)
-        if not already_set:
-            with open(self.settings_path, 'a') as f:
-                self._prep_heroku_setting(f)
-                f.write(f"\n    {new_setting}")
-            self.stdout.write("    Added STATICFILES_DIRS setting for Heroku.")
-        else:
-            self.stdout.write("    Found STATICFILES_DIRS setting for Heroku.")
+        msg_added = "    Added STATICFILES_DIRS setting for Heroku."
+        msg_already_set = "    Found STATICFILES_DIRS setting for Heroku."
+        self._add_heroku_setting(new_setting, msg_added, msg_already_set)
 
-        # Create folder for static files.
+
+    def _add_static_file_directory(self):
+        """Create a folder for static files, if it doesn't already exist.
+        """
         self.stdout.write("    Checking for static files directory...")
+
+        # Make sure there's a static files directory.
         static_files_dir = f"{self.project_root}/static"
         if os.path.exists(static_files_dir):
             if os.listdir(static_files_dir):
                 self.stdout.write("    Found non-empty static files directory.")
-            else:
-                # Directory exists, but it's empty and won't push to Heroku.
-                placeholder_file = f"{static_files_dir}/placeholder.txt"
-                with open(placeholder_file, 'w') as f:
-                    f.write("This is a placeholder file to make sure this folder is pushed to Heroku.")
-
-                self.stdout.write("    Found empty static files directory; added a placeholder file.")
+                return
         else:
-            # No static directory exists. Make one, and add a placeholder file.
             os.makedirs(static_files_dir)
-            placeholder_file = f"{static_files_dir}/placeholder.txt"
-            with open(placeholder_file, 'w') as f:
-                f.write("This is a placeholder file to make sure this folder is pushed to Heroku.")
+            self.stdout.write("    Created empty static files directory.")
 
-            self.stdout.write("    Created static files directory, and placeholder file.")
+        # Add a placeholder file to the empty static files directory.
+        placeholder_file = f"{static_files_dir}/placeholder.txt"
+        with open(placeholder_file, 'w') as f:
+            f.write("This is a placeholder file to make sure this folder is pushed to Heroku.")
+        self.stdout.write("    Added placeholder file to static files directory.")
 
 
     def _conclude_automate_all(self):
@@ -417,35 +364,36 @@ class Command(BaseCommand):
 
         self.stdout.write("  Adding changes...")
         subprocess.run(['git', 'add', '.'])
-
         self.stdout.write("  Committing changes...")
         subprocess.run(['git', 'commit', '-am', '"Configured project for deployment."'])
 
         self.stdout.write("  Pushing to heroku...")
 
-        # Get the current branch name, and push that branch.
-        # Get the first line of status output, and keep everything after "On branch ".
+        # Get the current branch name. Get the first line of status output,
+        #   and keep everything after "On branch ".
         git_status = subprocess.run(['git', 'status'], capture_output=True, text=True)
         self.current_branch = git_status.stdout.split('\n')[0][10:]
 
+        # Push current local branch to Heroku main branch.
         self.stdout.write(f"    Pushing branch {self.current_branch}...")
         if self.current_branch in ('main', 'master'):
             subprocess.run(['git', 'push', 'heroku', self.current_branch])
         else:
             subprocess.run(['git', 'push', 'heroku', f'{self.current_branch}:main'])
 
+        # Run initial set of migrations.
         self.stdout.write("  Migrating deployed app...")
         subprocess.run(['heroku', 'run', 'python', 'manage.py', 'migrate'])
 
+        # Open Heroku app, so it simply appears in user's browser.
         self.stdout.write("  Opening deployed app in a new browser tab...")
         subprocess.run(['heroku', 'open'])
 
 
     def _show_success_message(self):
         """After a successful run, show a message about what to do next."""
-        # DEV: This might be better structured as a block of text in a
-        #   separate file, pulled in from this method.
-        # Also:
+
+        # DEV:
         # - Say something about DEBUG setting.
         #   - Should also consider setting DEBUG = False in the Heroku-specific
         #     settings.
@@ -453,43 +401,18 @@ class Command(BaseCommand):
         #   creating a new deployment.
         #   - Describe ongoing approach of commit, push, migrate. Lots to consider
         #     when doing this on production app with users, make sure you learn.
+
         if self.automate_all:
-            msg = "\n\n--- Your project should now be deployed on Heroku. ---"
-            msg += "\n\nIt should have opened up in a new browser tab."
-            msg += """\n- If you see the message "There's nothing here, yet." try waiting"""
-            msg += "\n  a moment and then refreshing your browser."
-            msg += "\n- Sometimes when the process is automated there's a little lag"
-            msg += "\n  before the project is fully deployed."
-            msg += f"\n- You can also visit your project at {self.heroku_app_name}.herokuapp.com."
-            msg += "\n\nIf you make further changes and want to push them to Heroku,"
-            msg += "\ncommit your changes and then run the following command:"
-            if self.current_branch in ('main', 'master'):
-                msg += f"\n$ git push heroku {self.current_branch}"
-            else:
-                msg += f"\n$ git push heroku {self.current_branch}:main"
-            msg += "\n\nAlso, if you haven't already done so you should review the"
-            msg += "\ndocumentation for Python deployments on Heroku at:"
-            msg += "\n- https://devcenter.heroku.com/categories/python-support"
-            msg += "\n- This documentation will help you understand how to maintain"
-            msg += "\n  your deployment."
+            # Show how to make future deployments.
+            msg = d_msgs.success_msg_automate_all(self.heroku_app_name,
+                    self.current_branch)
         else:
-            msg = "\n\n--- Your project is now configured for deployment on Heroku. ---"
-            msg += "\n\nTo deploy your project, you will need to:"
-            msg += "\n- Commit the changes made in the configuration process."
-            msg += "\n- Push the changes to Heroku."
-            msg += "\n- Migrate the database on Heroku."
-            msg += "\n\nThe following commands should finish your initial deployment:"
-            if self.using_pipenv:
-                msg += "\n$ pipenv lock"
-            msg += "\n$ git add ."
-            msg += '\n$ git commit -am "Configured for Heroku deployment."'
-            msg += "\n$ git push heroku main"
-            msg += "\n$ heroku run python manage.py migrate"
-            msg += "\n\nAfter this, you can see your project by running 'heroku open'."
-            msg += f"\nOr, you can visit {self.heroku_app_name}.herokuapp.com."
+            # Show steps to finish the deployment process.
+            msg = d_msgs.success_msg(self.using_pipenv, self.heroku_app_name)
 
         self.stdout.write(msg)
 
+
     # --- Utility methods ---
 
     def _get_pipfile_requirements(self):
@@ -531,7 +454,6 @@ class Command(BaseCommand):
             self.stdout.write(f"    Found {root_package_name} in requirements file.")
         else:
             with open(self.req_txt_path, 'a') as f:
-                # DEV: Align these comments like they're aligned in Pipfile.
                 # Align comments, so we don't make req_txt file ugly.
                 #   Version specs are in package_name in req_txt approach.
                 tab_string = ' ' * (30 - len(package_name))
@@ -539,6 +461,7 @@ class Command(BaseCommand):
 
             self.stdout.write(f"    Added {package_name} to requirements.txt.")
 
+
     def _add_pipenv_pkg(self, package_name, version=""):
         """Add a package to Pipfile, if not already present."""
         pkg_present = any(package_name in r for r in self.requirements)
@@ -551,9 +474,7 @@ class Command(BaseCommand):
 
     def _write_pipfile_pkg(self, package_name, version=""):
         """Write package to Pipfile."""
-        # Write package name right after [packages].
-        #   For simple projects, this shouldn't cause any issues.
-        #   If ordering matters, we can address that later.
+
         with open(self.pipfile_path) as f:
             pipfile_text = f.read()
 
@@ -564,6 +485,9 @@ class Command(BaseCommand):
         #   Align at column 30, so take away name length, and version spec space.
         tab_string = ' ' * (30 - len(package_name) - 5 - len(version))
 
+        # Write package name right after [packages].
+        #   For simple projects, this shouldn't cause any issues.
+        #   If ordering matters, we can address that later.
         new_pkg_string = f'[packages]\n{package_name} = "{version}"{tab_string}# Added by simple_deploy command.'
         pipfile_text = pipfile_text.replace("[packages]", new_pkg_string)
 
@@ -579,12 +503,28 @@ class Command(BaseCommand):
         """
         return any(heroku_setting in line for line in self.current_heroku_settings_lines)
 
+
+    def _add_heroku_setting(self, new_setting, msg_added='',
+            msg_already_set=''):
+        """Add a new setting to the heroku-specific settings, if not already
+        present.
+        """
+        already_set = self._check_current_heroku_settings(new_setting)
+        if not already_set:
+            with open(self.settings_path, 'a') as f:
+                self._prep_heroku_setting(f)
+                f.write(f"\n    {new_setting}")
+                self.stdout.write(msg_added)
+        else:
+            self.stdout.write(msg_already_set)
+
+
     def _prep_heroku_setting(self, f_settings):
         """Add a block for Heroku-specific settings, if it doesn't already
         exist.
         """
-
         if not self.found_heroku_settings:
+            # DEV: Should check if `import os` already exists in settings file.
             f_settings.write("\nimport os")
             f_settings.write("\nif 'ON_HEROKU' in os.environ:")
 
